@@ -1,5 +1,6 @@
 compare_opts <- function(...,
                          tolerance = NULL,
+                         max_diffs = if (in_ci()) Inf else 10,
                          ignore_srcref = TRUE,
                          ignore_attr = FALSE,
                          ignore_encoding = TRUE,
@@ -11,6 +12,7 @@ compare_opts <- function(...,
 
   waldo <- list(
     tolerance = tolerance,
+    max_diffs = max_diffs,
     ignore_srcref = ignore_srcref,
     ignore_attr = ignore_attr,
     ignore_encoding = ignore_encoding,
@@ -40,9 +42,12 @@ old_opts <- function(..., tol, check.attributes, checkNames) {
   }
 
   if (!missing(...)) {
-    args <- names(substitute(alist(...))[-1])
-    args2 <- encodeString(args, quote = "`")
-    warn(paste0("Other arguments (", paste0(args2, collapse = ', '), ") ignored"))
+    args <- substitute(...())
+    exprs <- vapply(args, expr_deparse, character(1))
+    names <- names2(args)
+    exprs <- ifelse(names == "", exprs, paste0(names, " = ", exprs))
+
+    warn(paste0("Unused arguments (", paste0(exprs, collapse = ', '), ")"))
   }
 
   out
